==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/wafv2/kotlin/inputs/RuleGroupRuleStatementSizeConstraintStatementFieldToMatchCookiesMatchPatternArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.wafv2.kotlin.inputs

import com.pulumi.aws.wafv2.inputs.RuleGroupRuleStatementSizeConstraintStatementFieldToMatchCookiesMatchPatternArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property all An empty configuration block that is used for inspecting all headers.
 * @property excludedCookies
 * @property includedCookies
 */
public data class RuleGroupRuleStatementSizeConstraintStatementFieldToMatchCookiesMatchPatternArgs(
    public val all:
    Output<RuleGroupRuleStatementSizeConstraintStatementFieldToMatchCookiesMatchPatternAllArgs>? =
        null,
    public val excludedCookies: Output<List<String>>? = null,
    public val includedCookies: Output<List<String>>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.wafv2.inputs.RuleGroupRuleStatementSizeConstraintStatementFieldToMatchCookiesMatchPatternArgs> {
    override fun toJava():
        com.pulumi.aws.wafv2.inputs.RuleGroupRuleStatementSizeConstraintStatementFieldToMatchCookiesMatchPatternArgs =
        com.pulumi.aws.wafv2.inputs.RuleGroupRuleStatementSizeConstraintStatementFieldToMatchCookiesMatchPatternArgs.builder()
            .all(all?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .excludedCookies(excludedCookies?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .includedCookies(includedCookies?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [RuleGroupRuleStatementSizeConstraintStatementFieldToMatchCookiesMatchPatternArgs].
 */
@PulumiTagMarker
public class RuleGroupRuleStatementSizeConstraintStatementFieldToMatchCookiesMatchPatternArgsBuilder
internal constructor() {
    private var all:
        Output<RuleGroupRuleStatementSizeConstraintStatementFieldToMatchCookiesMatchPatternAllArgs>? =
        null

    private var excludedCookies: Output<List<String>>? = null

    private var includedCookies: Output<List<String>>? = null

    /**
     * @param value An empty configuration block that is used for inspecting all headers.
     */
    @JvmName("lfaprrppkrxqptlf")
    public suspend
    fun all(`value`: Output<RuleGroupRuleStatementSizeConstraintStatementFieldToMatchCookiesMatchPatternAllArgs>) {
        this.all = value
    }

    /**
     * @param value
     */
    @JvmName("dvoyxkhcvtqpawgr")
    public suspend fun excludedCookies(`value`: Output<List<String>>) {
        this.excludedCookies = value
    }

    @JvmName("mbttywtvjwatdiyu")
    public suspend fun excludedCookies(vararg values: Output<String>) {
        this.excludedCookies = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("rcdhvthgviikslud")
    public suspend fun excludedCookies(values: List<Output<String>>) {
        this.excludedCookies = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("hkbwodgetosfkuwm")
    public suspend fun includedCookies(`value`: Output<List<String>>) {
        this.includedCookies = value
    }

    @JvmName("obqqmwwudnwwabjj")
    public suspend fun includedCookies(vararg values: Output<String>) {
        this.includedCookies = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("gtewekrytdulfqwh")
    public suspend fun includedCookies(values: List<Output<String>>) {
        this.includedCookies = Output.all(values)
    }

    /**
     * @param value An empty configuration block that is used for inspecting all headers.
     */
    @JvmName("fytxfdbxedjopbmu")
    public suspend
    fun all(`value`: RuleGroupRuleStatementSizeConstraintStatementFieldToMatchCookiesMatchPatternAllArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.all = mapped
    }

    /**
     * @param argument An empty configuration block that is used for inspecting all headers.
     */
    @JvmName("pqwxmormfteuvqry")
    public suspend
    fun all(argument: suspend RuleGroupRuleStatementSizeConstraintStatementFieldToMatchCookiesMatchPatternAllArgsBuilder.() -> Unit) {
        val toBeMapped =
            RuleGroupRuleStatementSizeConstraintStatementFieldToMatchCookiesMatchPatternAllArgsBuilder().applySuspend {
                argument()
            }.build()
        val mapped = of(toBeMapped)
        this.all = mapped
    }

    /**
     * @param value
     */
    @JvmName("bretisvosggmadce")
    public suspend fun excludedCookies(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.excludedCookies = mapped
    }

    /**
     * @param values
     */
    @JvmName("panbpujeuyvdxrbv")
    public suspend fun excludedCookies(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.excludedCookies = mapped
    }

    /**
     * @param value
     */
    @JvmName("inissxgsxfjkuour")
    public suspend fun includedCookies(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.includedCookies = mapped
    }

    /**
     * @param values
     */
    @JvmName("hstqqtbpwigloduk")
    public suspend fun includedCookies(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.includedCookies = mapped
    }

    internal fun build():
        RuleGroupRuleStatementSizeConstraintStatementFieldToMatchCookiesMatchPatternArgs =
        RuleGroupRuleStatementSizeConstraintStatementFieldToMatchCookiesMatchPatternArgs(
            all = all,
            excludedCookies = excludedCookies,
            includedCookies = includedCookies,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/wafv2/kotlin/inputs/RuleGroupRuleStatementSizeConstraintStatementFieldToMatchCookiesMatchPatternArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.wafv2.kotlin.inputs

import com.pulumi.aws.wafv2.inputs.RuleGroupRuleStatementSizeConstraintStatementFieldToMatchCookiesMatchPatternArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property all An empty configuration block that is used for inspecting all headers.
 * @property excludedCookies
 * @property includedCookies
 */
public data class RuleGroupRuleStatementSizeConstraintStatementFieldToMatchCookiesMatchPatternArgs(
    public val all: Output<RuleGroupRuleStatementSizeConstraintStatementFieldToMatchCookiesMatchPatternAllArgs>? =
        null,
    public val excludedCookies: Output<List<String>>? = null,
    public val includedCookies: Output<List<String>>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.wafv2.inputs.RuleGroupRuleStatementSizeConstraintStatementFieldToMatchCookiesMatchPatternArgs> {
    override fun toJava(): com.pulumi.aws.wafv2.inputs.RuleGroupRuleStatementSizeConstraintStatementFieldToMatchCookiesMatchPatternArgs =
        com.pulumi.aws.wafv2.inputs.RuleGroupRuleStatementSizeConstraintStatementFieldToMatchCookiesMatchPatternArgs.builder()
            .all(all?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .excludedCookies(excludedCookies?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .includedCookies(includedCookies?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [RuleGroupRuleStatementSizeConstraintStatementFieldToMatchCookiesMatchPatternArgs].
 */
@PulumiTagMarker
public class RuleGroupRuleStatementSizeConstraintStatementFieldToMatchCookiesMatchPatternArgsBuilder
internal constructor() {
    private var all:
        Output<RuleGroupRuleStatementSizeConstraintStatementFieldToMatchCookiesMatchPatternAllArgs>? =
        null

    private var excludedCookies: Output<List<String>>? = null

    private var includedCookies: Output<List<String>>? = null

    /**
     * @param value An empty configuration block that is used for inspecting all headers.
     */
    @JvmName("bulchgmxvavskwho")
    public suspend fun all(`value`: Output<RuleGroupRuleStatementSizeConstraintStatementFieldToMatchCookiesMatchPatternAllArgs>) {
        this.all = value
    }

    /**
     * @param value
     */
    @JvmName("dpogtflpprypxmlq")
    public suspend fun excludedCookies(`value`: Output<List<String>>) {
        this.excludedCookies = value
    }

    @JvmName("wgylsovglvfndegd")
    public suspend fun excludedCookies(vararg values: Output<String>) {
        this.excludedCookies = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("yilreaoejkdccchq")
    public suspend fun excludedCookies(values: List<Output<String>>) {
        this.excludedCookies = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("qvusdamfolsleani")
    public suspend fun includedCookies(`value`: Output<List<String>>) {
        this.includedCookies = value
    }

    @JvmName("uhhjjuenvahylgys")
    public suspend fun includedCookies(vararg values: Output<String>) {
        this.includedCookies = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("lfqiptcgqgrwfcoq")
    public suspend fun includedCookies(values: List<Output<String>>) {
        this.includedCookies = Output.all(values)
    }

    /**
     * @param value An empty configuration block that is used for inspecting all headers.
     */
    @JvmName("viusfkyevognjifw")
    public suspend fun all(`value`: RuleGroupRuleStatementSizeConstraintStatementFieldToMatchCookiesMatchPatternAllArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.all = mapped
    }

    /**
     * @param argument An empty configuration block that is used for inspecting all headers.
     */
    @JvmName("kaiifprketxaaadp")
    public suspend fun all(argument: suspend RuleGroupRuleStatementSizeConstraintStatementFieldToMatchCookiesMatchPatternAllArgsBuilder.() -> Unit) {
        val toBeMapped =
            RuleGroupRuleStatementSizeConstraintStatementFieldToMatchCookiesMatchPatternAllArgsBuilder().applySuspend {
                argument()
            }.build()
        val mapped = of(toBeMapped)
        this.all = mapped
    }

    /**
     * @param value
     */
    @JvmName("arxcwyoecjcctwsm")
    public suspend fun excludedCookies(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.excludedCookies = mapped
    }

    /**
     * @param values
     */
    @JvmName("ldifedyvbfdhehec")
    public suspend fun excludedCookies(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.excludedCookies = mapped
    }

    /**
     * @param value
     */
    @JvmName("kvrdjwaysvimwllj")
    public suspend fun includedCookies(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.includedCookies = mapped
    }

    /**
     * @param values
     */
    @JvmName("xcvqssokbnlbfwxd")
    public suspend fun includedCookies(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.includedCookies = mapped
    }

    internal fun build(): RuleGroupRuleStatementSizeConstraintStatementFieldToMatchCookiesMatchPatternArgs =
        RuleGroupRuleStatementSizeConstraintStatementFieldToMatchCookiesMatchPatternArgs(
            all = all,
            excludedCookies = excludedCookies,
            includedCookies = includedCookies,
        )
}
